@@ -15,10 +15,11 @@ class InvoiceLine(ModelSQL, ModelView):
                 'invisible': Not(Equal(Eval('type'), 'line')),
             })
 
-    def _view_look_dom_arch(self, tree, type):
+    def _view_look_dom_arch(self, tree, type, field_children=None):
         analytic_account_obj = self.pool.get('analytic_account.account')
         analytic_account_obj.convert_view(tree)
-        arch, fields = super(InvoiceLine, self)._view_look_dom_arch(tree, type)
+        arch, fields = super(InvoiceLine, self)._view_look_dom_arch(tree, type,
+            field_children=field_children)
         return arch, fields
 
     def fields_get(self, fields_names=None):
@@ -182,33 +183,23 @@ class InvoiceLine(ModelSQL, ModelView):
             return new_ids[0]
         return new_ids
 
-    def _credit(self, line):
-        selection_obj = self.pool.get('analytic_account.account.selection')
-
-        result = super(InvoiceLine, self)._credit(line)
-
-        if line.analytic_accounts:
-            selection_id = selection_obj.copy(line.analytic_accounts.id)
-            result['analytic_accounts'] = selection_id
-        return result
-
     def get_move_line(self, line):
-        res = super(InvoiceLine, self).get_move_line(line)
+        values = super(InvoiceLine, self).get_move_line(line)
         if line.analytic_accounts and line.analytic_accounts.accounts:
-            res['analytic_lines'] = []
-            for account in line.analytic_accounts.accounts:
-                vals = {}
-                vals['name'] = line.description
-                vals['debit'] = res['debit']
-                vals['credit'] = res['credit']
-                vals['account'] = account.id
-                vals['journal'] = line.invoice.journal.id
-                vals['date'] = (line.invoice.accounting_date
-                    or line.invoice.invoice_date)
-                vals['reference'] = line.invoice.reference
-                vals['party'] = line.invoice.party.id
-                res['analytic_lines'].append(('create', vals))
-        return res
+            for value in values:
+                value['analytic_lines'] = []
+                for account in line.analytic_accounts.accounts:
+                    vals = {}
+                    vals['name'] = line.description
+                    vals['debit'] = value['debit']
+                    vals['credit'] = value['credit']
+                    vals['account'] = account.id
+                    vals['journal'] = line.invoice.journal.id
+                    vals['date'] = line.invoice.invoice_date
+                    vals['reference'] = line.invoice.reference
+                    vals['party'] = line.invoice.party.id
+                    value['analytic_lines'].append(('create', vals))
+        return values
 
 InvoiceLine()
 
